@@ -1,8 +1,11 @@
+use crate::WartsSized;
 use deku::bitvec::{BitSlice, BitVec, Msb0};
 use deku::ctx::Endian;
 use deku::{DekuError, DekuRead, DekuWrite};
 use std::fmt::{Debug, Formatter};
 
+// TODO: Automatically generate `fixup()` methods with a derive macro?
+
 /// A variable length flag structure.
 ///
 /// From the [`warts(5)`](https://www.caida.org/catalog/software/scamper/man/warts.5.pdf) man page:
@@ -124,6 +127,19 @@ impl DekuWrite<Endian> for Flags {
     }
 }
 
+impl Default for Flags {
+    fn default() -> Self {
+        Flags::new(0)
+    }
+}
+
+impl WartsSized for Flags {
+    fn warts_size(&self) -> usize {
+        // TODO: Better implementation...
+        self.to_vec().len()
+    }
+}
+
 #[cfg(test)]
 mod tests {
     use crate::Flags;
