@@ -4,20 +4,29 @@
 //!
 //! For examples, see the [`examples/`](https://github.com/dioptra-io/warts/tree/main/examples) directory.
 
+#[macro_use]
+mod macros;
+
 mod address;
+mod cycle;
 mod flags;
 mod icmpext;
+mod list;
 mod object;
 mod ping;
+mod sized;
 mod timeval;
 mod trace;
 mod tracelb;
 
 pub use address::*;
+pub use cycle::*;
 pub use flags::*;
 pub use icmpext::*;
+pub use list::*;
 pub use object::*;
 pub use ping::*;
+pub use sized::*;
 pub use timeval::*;
 pub use trace::*;
 pub use tracelb::*;
