@@ -1,5 +1,7 @@
+use crate::WartsSized;
 use chrono::NaiveDateTime;
 use deku::prelude::*;
+use std::mem::size_of_val;
 
 /// A timestamp with a microsecond resolution.
 /// ```
@@ -32,6 +34,12 @@ impl From<NaiveDateTime> for Timeval {
     }
 }
 
+impl WartsSized for Timeval {
+    fn warts_size(&self) -> usize {
+        size_of_val(self)
+    }
+}
+
 #[cfg(test)]
 mod tests {
     use crate::Timeval;
